@@ -5,7 +5,7 @@
 # r8125 is the Linux device driver released for Realtek 2.5 Gigabit Ethernet
 # controllers with PCI-Express interface.
 #
-# Copyright(c) 2024 Realtek Semiconductor Corp. All rights reserved.
+# Copyright(c) 2025 Realtek Semiconductor Corp. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -104,10 +104,10 @@ static int rtl8125_eeprom_cmd_done(struct rtl8125_private *tp)
                 x = RTL_R8(tp, Cfg9346);
 
                 if (x & Cfg9346_EEDO) {
-                        fsleep(RTL_CLOCK_RATE * 2 * 3);
+                        udelay(RTL_CLOCK_RATE * 2 * 3);
                         return 0;
                 }
-                fsleep(1);
+                udelay(1);
         }
 
         return -1;
@@ -198,14 +198,14 @@ void rtl8125_raise_clock(struct rtl8125_private *tp, u8 *x)
 {
         *x = *x | Cfg9346_EESK;
         RTL_W8(tp, Cfg9346, *x);
-        fsleep(RTL_CLOCK_RATE);
+        udelay(RTL_CLOCK_RATE);
 }
 
 void rtl8125_lower_clock(struct rtl8125_private *tp, u8 *x)
 {
         *x = *x & ~Cfg9346_EESK;
         RTL_W8(tp, Cfg9346, *x);
-        fsleep(RTL_CLOCK_RATE);
+        udelay(RTL_CLOCK_RATE);
 }
 
 void rtl8125_shift_out_bits(struct rtl8125_private *tp, int data, int count)
@@ -224,7 +224,7 @@ void rtl8125_shift_out_bits(struct rtl8125_private *tp, int data, int count)
                         x &= ~Cfg9346_EEDI;
 
                 RTL_W8(tp, Cfg9346, x);
-                fsleep(RTL_CLOCK_RATE);
+                udelay(RTL_CLOCK_RATE);
                 rtl8125_raise_clock(tp, &x);
                 rtl8125_lower_clock(tp, &x);
                 mask = mask >> 1;
@@ -267,7 +267,7 @@ void rtl8125_stand_by(struct rtl8125_private *tp)
         x = RTL_R8(tp, Cfg9346);
         x &= ~(Cfg9346_EECS | Cfg9346_EESK);
         RTL_W8(tp, Cfg9346, x);
-        fsleep(RTL_CLOCK_RATE);
+        udelay(RTL_CLOCK_RATE);
 
         x |= Cfg9346_EECS;
         RTL_W8(tp, Cfg9346, x);
@@ -278,7 +278,7 @@ void rtl8125_set_eeprom_sel_low(struct rtl8125_private *tp)
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1 | Cfg9346_EESK);
 
-        fsleep(20);
+        udelay(20);
 
         RTL_W8(tp, Cfg9346, Cfg9346_EEM1);
 }
